extensions [ nw ]
globals [ total-delta-activity max-size cat-list iqv first-max-activity ]
turtles-own [ x y vertex ext_act int_act value ext_fr int_fr delta_fr indegree outdegree degree modularity_class eigencentrality strongcompnum clustering homophily inactive tick-probability ]
links-own [ homophily-weight reciprocated ]

; ----- BUTTONS -----

to init
  clear-all
  reset-ticks
  nw:set-context turtles links
  nw:load-graphml network-file [
    set shape "circle"
    set size 1
    set label ""
    set color modularity_class + 25
  ]

  ask turtles [
    set homophily 99
  ]

  set-coordinates
  normalize-ticks
  calculate-properties
  calculate-homophily
  calculate-weight
  calculate-value
  calculate-iqv
  set max-size [int_act] of max-one-of turtles [int_act]
  set-size
  set first-max-activity max-activity
end

to layout
  ifelse show-labels
  [ ask turtles [ set label vertex ] ]
  [ ask turtles [ set label "" ] ]
  repeat layout-impact [ layout-spring turtles links 1 5 1 ] ;; lays the nodes in a triangle
end

to randomize
  ask turtles [
    setxy random-xcor random-ycor
  ]
end

to simulate
  ; Calculate the new activity of each turtle

  ifelse value-based [
    simulate-value
  ]
  [
    simulate-activity
    calculate-value
  ]

  set-size
  if (ticks = max-ticks) [ stop ]
  tick
end

to one-step
  simulate
  tick
end

to save
  let len-filename length network-file - 8
  let filename substring network-file 0 len-filename
  nw:save-graphml (word filename "-" ticks ".graphml" )
end

; ----- TOOLS -----

to set-coordinates
  ;Determine max screen width and height
  let screen-width abs(min-pxcor) + max-pxcor
  let screen-height abs(min-pycor) + max-pycor

  ;Get smallest and largest coordinates + 10% or border
  let min-x [x] of min-one-of turtles [x] * 1.1
  let max-x [x] of max-one-of turtles [x] * 1.1
  let min-y [y] of min-one-of turtles [y] * 1.1
  let max-y [y] of max-one-of turtles [y] * 1.1

  let canvas-width abs(min-x) + max-x
  let canvas-height abs(min-y) + max-y

  ask turtles [
    let node-x (x + abs(min-x)) * (screen-width / canvas-width) + min-pxcor
    let node-y (y + abs(min-y)) * (screen-height / canvas-height) + min-pycor
    setxy node-x node-y
  ]
end

to set-size
  ask turtles [
    ifelse (int_act > 0) [ set size ( (int_act * node-scale) / (max-size) ) ] [ set size 0 ]
  ]
end

to calculate-properties
  ask turtles [
    if (degree > 0) [
      set int_fr (indegree / degree)
      set delta_fr int_fr - ext_fr
      ifelse ( int_act <= inactivity-threshold ) [ set inactive 1 ] [ set inactive 0 ]
    ]
  ]
end

to calculate-homophily

  ; Count number of nodes with not homophily (set to 99 by default)
  ; If this count is > 0
  ;   Take one node with no homophily assigned
  ;   Ask all nodes from the same cluster
  ;   Ask all outgoing ties of these nodes
  ;   Count the tie as internal or external regarding the end2
  ;   Calculate the homophily ratio
  ;   Assign this ratio to all nodes with the same cluster
  ;   Execute procedure once more
  ; Otherwise stop

  if (count turtles with [ homophily = 99 ] > 0) [
    let internal-links 0
    let external-links 0
    ask one-of turtles with [ homophily = 99 ] [
      let current-cluster strongcompnum
      ask turtles with [ strongcompnum = current-cluster ] [
        ask my-out-links [
          ifelse ( [strongcompnum] of end2 = current-cluster ) [
            set internal-links internal-links + 1
          ]
          [
            set external-links external-links + 1
          ]
        ]
      ]
      ask turtles with [ strongcompnum = current-cluster ]  [
        ifelse (internal-links + external-links > 0) [
          set homophily internal-links / ( external-links + internal-links )
        ]
        [
          set homophily 1
        ]
      ]
    ]
    calculate-homophily
  ]
end

to calculate-weight

  ; For each node assign a weight to the outgoing ties
  ; The weight is 1/d of the node itself * the homophily for internal links
  ; and 1-homophily for external links, where d is the total degrees of the node

  ask turtles [
    ask my-out-links [
      ifelse ( [strongcompnum] of end1 = [strongcompnum] of end2 )
      [
        ifelse ( [degree] of end1 > 0 ) [
          set homophily-weight ( 1 / ([degree] of end1 ) ) * [homophily] of end1
        ] [ set homophily-weight 1 ]
      ]
      [
        ifelse ( [degree] of end1 > 0 ) [
          set homophily-weight ( 1 / ([degree] of end1 ) ) * ( 1 - [homophily] of end1 )
        ] [ set homophily-weight 1 ]
      ]
    ]
  ]
end

to provide-incentive
  if (add-incentives) [
    if ( ( random 100 / 100 < incentive-slider ) or ( not enable-randomizer ) ) [
      ask one-of turtles [
        set int_act ( random ( first-max-activity * 100 ) / 100 )
      ]
    ]
  ]
end

to simulate-activity

  ; For each node
  ; Calculate the sum of all (activity * weight) of its neighbors
  ; Add the nodes own activity (average is already included in homophily-weight
  ; Upate the value for the nodes

  ; Create a random number, for each node with tick-probability >= random number
  ; Get their followers (in-inks) and update them with the int_act
  let new-act 0
  set total-delta-activity 0
  ask turtles with [ tick-probability >= ( random 1000 / 1000 ) ] [
    ask my-in-links [
      set new-act ( homophily-weight * ( [int_act] of end2 - [int_act] of end1 ) )
      if ( ( random 100 / 100 < randomizer ) or ( not enable-randomizer ) ) [
        ask end1 [
          set int_act ( self-weight * int_act ) + ( 1 - self-weight ) * new-act
          ;ifelse ( new-act < inactivity-threshold ) [ set inactive 1 ] [ set inactive 0 ]
          ifelse ( int_act <= inactivity-threshold ) [ set inactive 1 ] [ set inactive 0 ]
        ]
      ]
    ]
    set total-delta-activity ( total-delta-activity + new-act )
  ]
  provide-incentive

  ; Potentially adjust with centrality (importance)
  ; by taking the highes centrality measure of all of its neighbors & self
  ; and dividing each centrality by this maximum value ( so normalize to [0, 1] )
  ; and then mulitply the transferrable activity with this factor

end

to simulate-value

  ; For each node
  ; Calculate the sum of all (value * weight) of its neighbors
  ; Add the nodes own value (average is already included in homophily-weight

  ; Create a random number, for each node with tick-probability >= random number
  ; Get their followers (in-inks) and update them with the int_act
  let new-value 0
  let new-act 0
  set total-delta-activity 0
  ask turtles with [ tick-probability >= ( random 1000 / 1000 ) ] [
    ask my-in-links [
      set new-value ( 1 - self-weight ) * ( homophily-weight * [value] of end2 ) + ( self-weight * [value] of end1 )
      if ( ( random 100 / 100 < randomizer ) or ( not enable-randomizer ) ) [
        ask end1 [
          ;ifelse ( new-value < value - inactivity-threshold ) and ( new-value > value + inactivity-threshold ) [ set inactive 0 ] [ set inactive 1 ]
          ifelse ( new-value != 1 ) [
            set new-act ( ( ( - 1 * new-value ) - 1 ) * ext_act ) / ( new-value - 1 )
          ] [ set new-act int_act ]
          set value new-value
          let delta-act new-act - int_act
          set total-delta-activity ( total-delta-activity + delta-act )
          set int_act new-act
          ifelse ( int_act <= inactivity-threshold ) [ set inactive 1 ] [ set inactive 0 ]
        ]
      ]
    ]
    set total-delta-activity ( total-delta-activity + new-act )
  ]
  provide-incentive

end

to calculate-value
  ask turtles [
    ifelse (int_act + ext_act > 0)
    [ set value (int_act - ext_act) / (int_act + ext_act) ]
    [ set value 0 ]
  ]
end

to check-reciprocation
  ask links with [ reciprocated = 0 ] [
    ifelse count links with [ ( end1 = [end2] of myself ) and ( end2 = [end1] of myself ) ] > 0
    [ set reciprocated 1]
    [ set reciprocated -1]
  ]
end

to normalize-ticks

  ; Normalizing the ticks is required for proper time simulation, where the largest tweeter tweets every tick
  ask turtles [
    set tick-probability int_act / max-activity
  ]
end

to calculate-iqv

  ; Calculating the IQV results in an indication for potential collective action
  ; The higher the score, the higher the heterogeneity, score 1 means 50% chance eternally connected

  set cat-list [ ]
  ask turtles [
    set cat-list lput strongcompnum cat-list
  ]
  set cat-list remove-duplicates cat-list
  let cat-sum 0
  foreach cat-list [ [?1] ->
    let cat-prop count turtles with [ strongcompnum = ?1 ] / count turtles
    set cat-sum cat-sum + cat-prop ^ 2
  ]
  ifelse ( length cat-list = 0 ) or ( length cat-list = 1 )
  [ set iqv 0 ]
  [ set iqv ( 1 - cat-sum ) / ( 1 - ( 1 / length cat-list ) ) ]
end

; ----- REPORTERS -----

to-report median-value
    report median [value] of turtles
end

to-report mean-delta-fr
  report mean [delta_fr] of turtles
end

to-report mean-indegree-active
  report mean [indegree] of turtles with [int_act > 0]
end

to-report node-count
  report count turtles
end

to-report active-nodes
  ;report count turtles with [int_act > inactivity-threshold]
  report count turtles with [inactive = 0]
end

to-report inactive-nodes
  ;report count turtles with [int_act <= inactivity-threshold]
  report count turtles with [inactive = 1]
end

to-report links-count
  report count links
end

to-report free-riders
  report inactive-nodes / node-count
end

to-report mean-homophily
  report mean [homophily] of turtles
end

to-report total-activity
  report sum [int_act] of turtles
end

to-report total-value
  report sum [value] of turtles with [(value >= 0) or (value <= 0)]
end

to-report mean-value
  ifelse (ticks > 0) [
    ;report mean [value] of turtles with [(value >= 0) or (value <= 0)]
    report mean [value] of turtles
  ] [ report 0 ]
end

to-report mean-indegree
  let total-in-links 0
  ask turtles [
    set total-in-links total-in-links + count my-in-links
  ]
  report total-in-links / node-count
end

to-report total-delta
  report total-delta-activity
end

to-report count-reciprocated
  report ( count links with [ reciprocated = 1 ] ) / 2
end

to-report relative-reciprocated
  report ( ( count links with [ reciprocated = 1 ] ) / 2 ) / links-count
end

to-report turtle-values
  report [value] of turtles
  ;ask turtles [
  ;  report value
  ;]
end

to-report max-activity
  report max [int_act] of turtles
end

to-report index-of-variation
  report iqv
end

to-report tick-duration
  report 1 / max-activity
end
@#$#@#$#@
GRAPHICS-WINDOW
251
10
664
424
-1
-1
12.28
1
10
1
1
1
0
0
0
1
-16
16
-16
16
1
1
1
ticks
30.0

BUTTON
136
56
249
89
initialize data
init
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
136
124
249
157
update layout
layout
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
22
90
135
123
layout-impact
layout-impact
0
500
97.0
1
1
NIL
HORIZONTAL

SLIDER
22
56
135
89
node-scale
node-scale
1
10
4.0
0.5
1
NIL
HORIZONTAL

BUTTON
136
90
249
123
randomize
randomize
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
671
56
805
101
NIL
median-value
5
1
11

SWITCH
22
124
135
157
show-labels
show-labels
1
1
-1000

MONITOR
671
102
805
147
NIL
mean-indegree-active
5
1
11

MONITOR
671
148
805
193
NIL
mean-delta-fr
5
1
11

TEXTBOX
672
10
822
52
Measures for Importance\nmedian-value: ~V\nmean-delta-fr: _dF
11
15.0
1

SLIDER
807
68
1065
101
inactivity-threshold
inactivity-threshold
0
1
0.0
0.01
1
NIL
HORIZONTAL

MONITOR
807
102
892
147
NIL
active-nodes
17
1
11

MONITOR
894
102
979
147
NIL
inactive-nodes
17
1
11

MONITOR
980
102
1065
147
NIL
node-count
17
1
11

TEXTBOX
809
10
1055
67
Inactovoty threshold is the activity level at which a node is classified as inactive. \nIf int_act <= inactivity-threshold then the node is inactive.
11
15.0
1

MONITOR
136
158
249
203
NIL
free-riders
5
1
11

MONITOR
136
204
248
249
NIL
mean-homophily
5
1
11

BUTTON
22
219
135
252
NIL
simulate
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
22
158
135
218
max-ticks
9000.0
1
0
Number

PLOT
872
195
1072
345
Average Value
ticks
mean-value
0.0
1.0
-1.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean-value"
"zero" 1.0 0 -2674135 true "" "plot 0"

MONITOR
565
451
669
496
NIL
total-activity
5
1
11

MONITOR
807
148
892
193
NIL
links-count
17
1
11

MONITOR
894
148
979
193
NIL
total-value
5
1
11

PLOT
671
195
871
345
Total Value
ticks
total-value
0.0
1.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot total-value"
"zero" 1.0 0 -2674135 true "" "plot 0"

MONITOR
980
148
1065
193
NIL
mean-value
5
1
11

MONITOR
136
388
248
433
NIL
mean-indegree
5
1
11

MONITOR
469
451
564
496
NIL
total-delta-activity
5
1
11

PLOT
671
346
871
496
Total Activity
ticks
effectiveness
0.0
1.0
-0.01
0.01
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot total-activity"
"zero" 1.0 0 -2674135 true "" "plot 0"

CHOOSER
22
10
249
55
network-file
network-file
"ia4si.graphml" "ia4si-random.graphml" "myaccessibleeu.graphml" "myaccessibleeu-random.graphml" "dcentproject.graphml" "dcentproject-random.graphml" "usempproject.graphml" "usempproject-random.graphml" "webcosi.graphml" "webcosi-random.graphml" "comradesproject.graphml" "comradesproject-random.graphml"
10

BUTTON
22
253
135
286
NIL
one-step
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
22
321
134
366
NIL
count-reciprocated
17
1
11

SLIDER
1066
126
1192
159
randomizer
randomizer
0
1
0.1
0.05
1
NIL
HORIZONTAL

SWITCH
1066
92
1192
125
enable-randomizer
enable-randomizer
0
1
-1000

BUTTON
22
413
134
446
NIL
check-reciprocation
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
22
367
134
412
NIL
relative-reciprocated
5
1
11

PLOT
1073
346
1273
496
Activity Histogram
Activity
Frequency
0.0
10.0
0.0
1.0
true
false
";set-plot-x-range min [int_act] of turtles max [int_act] of turtles\n;set-plot-y-range 0 count turtles\nset-histogram-num-bars 15" ""
PENS
"homophily" 1.0 1 -2674135 true "" "histogram [int_act] of turtles"

BUTTON
22
287
135
320
NIL
save
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
1066
160
1192
193
value-based
value-based
0
1
-1000

MONITOR
136
296
248
341
NIL
max-activity
5
1
11

TEXTBOX
1073
10
1293
80
The randomizer incorporates some randomness in actually changing a nodes behavior, assuming that not always people respond on the activity (if random value > slider, then update the data)
11
15.0
1

PLOT
1073
195
1273
345
Value Histogram
Value
Frequency
-1.0
1.0
0.0
1.0
true
false
"set-histogram-num-bars 15" ""
PENS
"default" 1.0 1 -2674135 true "" "histogram [value] of turtles"

PLOT
872
346
1072
496
Activity Impact
ticks
delta-activity
0.0
1.0
-0.1
0.1
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot total-delta-activity"
"pen-1" 1.0 0 -2674135 true "" "plot 0"

SLIDER
1193
92
1314
125
self-weight
self-weight
0
1
0.5
0.01
1
NIL
HORIZONTAL

MONITOR
136
250
248
295
NIL
index-of-variation
5
1
11

SWITCH
1193
160
1314
193
add-incentives
add-incentives
1
1
-1000

SLIDER
1193
126
1314
159
incentive-slider
incentive-slider
0
0.05
0.003
0.001
1
NIL
HORIZONTAL

MONITOR
136
342
248
387
NIL
tick-duration
5
1
11

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
